@@ -15,7 +15,7 @@
 # NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
 # WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
-# $Id: isc-config.sh.in,v 1.7.4.1 2001/01/09 22:31:08 bwelling Exp $
+# $Id: isc-config.sh.in,v 1.10 2001/04/16 22:29:55 bwelling Exp $
 
 prefix=/usr/local
 exec_prefix=${prefix}
@@ -33,6 +33,8 @@ Options:
 	[--cflags]
 Libraries:
 	isc
+	isccc
+	isccfg
 	dns
 	lwres
 EOF
@@ -66,7 +68,7 @@ while test $# -gt 0; do
 		echo_exec_prefix=true
 		;;
 	--version)
-		echo VERSION=9.1.3
+		echo VERSION=9.2.1
 		exit 0
 		;;
 	--cflags)
@@ -78,8 +80,17 @@ while test $# -gt 0; do
 	isc)
 		libisc=true;
 		;;
+	isccc)
+		libisccc=true;
+		libisc=true;
+		;;
+	isccfg)
+		libisccfg=true;
+		libisc=true;
+		;;
 	dns)
 		libdns=true;
+		libisc=true;
 		;;
 	lwres)
 		liblwres=true;
@@ -98,8 +109,8 @@ if test x"$echo_exec_prefix" = x"true" ; then
 fi
 if test x"$echo_cflags" = x"true"; then
 	includes="-I${exec_prefix}/include"
-	if test x"$libdns" = x"true" -o x"$libisc" = x"true"; then
-		includes="$includes -D_REENTRANT   -D_THREAD_SAFE  -pthread"
+	if test x"$libisc" = x"true"; then
+		includes="$includes    "
 	fi
 	echo $includes
 fi
@@ -110,14 +121,19 @@ if test x"$echo_libs" = x"true"; then
 	fi
 	if test x"$libdns" = x"true" ; then
 		libs="$libs -ldns "
-		needothers=true
+	fi
+	if test x"$libisccfg" = x"true" ; then
+		libs="$libs -lisccfg"
+	fi
+	if test x"$libisccc" = x"true" ; then
+		libs="$libs -lisccc"
 	fi
 	if test x"$libisc" = x"true" ; then
 		libs="$libs -lisc"
 		needothers=true
 	fi
 	if test x"$needothers" = x"true" ; then
-		libs="$libs  -pthread -lpthread "
+		libs="$libs  "
 	fi
 	echo $libs
 fi
